@@ -79,7 +79,9 @@ TranslateNameChooser::TranslateNameChooser(PhyView* phyview) :
   fileFilters_ << "Coma separated columns (*.txt *.csv)"
                << "Tab separated columns (*.txt *.csv)";
   fileDialog_->setNameFilters(fileFilters_);
-
+  hasHeader_ = new QCheckBox(tr("File has header line"));
+  QGridLayout *dlayout = dynamic_cast<QGridLayout*>(fileDialog_->layout());
+  dlayout->addWidget(hasHeader_, 4, 0);
   QFormLayout* layout = new QFormLayout;
   fromList_ = new QComboBox;
   toList_   = new QComboBox;
@@ -102,13 +104,20 @@ void TranslateNameChooser::translateTree(TreeTemplate<Node>& tree)
     if (fileDialog_->selectedNameFilter() == fileFilters_[1])
       sep = "\t";
     ifstream file(path[0].toStdString().c_str(), ios::in);
-    DataTable* table = DataTable::read(file, sep);
+    DataTable* table = DataTable::read(file, sep, hasHeader_->isChecked());
 
     //Clean button groups:
     fromList_->clear();
     toList_->clear();
 
     //Now add the new ones:
+    if (!hasHeader_->isChecked()) {
+      vector<string> names;
+      for (unsigned int i = 0; i < table->getNumberOfColumns(); ++i) {
+        names.push_back("Col" + TextTools::toString(i + 1));
+      }
+      table->setColumnNames(names);
+    }
     for (unsigned int i = 0; i < table->getNumberOfColumns(); ++i) {
       fromList_->addItem(QtTools::toQt(table->getColumnName(i)));
         toList_->addItem(QtTools::toQt(table->getColumnName(i)));
@@ -940,15 +949,15 @@ void PhyView::exit()
 void PhyView::aboutBpp()
 {
   QMessageBox msgBox;
-  msgBox.setText("Bio++ 2.0.1.");
-  msgBox.setInformativeText("bpp-core 2.0.2\nbpp-seq 2.0.2.\nbpp-phyl 2.0.2.\nbpp-qt 2.0.1");
+  msgBox.setText("Bio++ 2.1.0.");
+  msgBox.setInformativeText("bpp-core 2.1.0\nbpp-seq 2.1.0.\nbpp-phyl 2.1.0.\nbpp-qt 2.1.0");
   msgBox.exec();
 }
 
 void PhyView::about()
 {
   QMessageBox msgBox;
-  msgBox.setText("This is Bio++ Phy View version 0.2.0.");
+  msgBox.setText("This is Bio++ Phy View version 0.3.0.");
   msgBox.setInformativeText("Julien Dutheil <julien.dutheil@univ-montp2.fr>.");
   msgBox.exec();
 }
